{% extends "base.html" %}
{% from "macros.html" import render_field, form_tag %}

{% block content %}
  {% call form_tag(form) %}
    <div class="row">
      <div class="col-md-9 col-sm-8 col-xs-12">
        <h1>On-boarding Token Missing</h1>
      </div>
    </div>
    <div class="row">
      <div class="col-md-6 col-sm-6 col-xs-12">
        {{ render_field(form.token) }}
        <button type="submit" class="btn btn-primary" value="Save">Submit</button>
      </div>
    </div>
  {% endcall %}
{% endblock %}
